← Cloudflare Ruleset Engine / ruleset-engine / rulesets-api
Výpis a zobrazení sad pravidel
Pomocí operací API popsaných v následujících částech zobrazíte seznam a podrobnosti rulesetů na úrovni účtu nebo zóny.
- Seznam existujících sad pravidel
- Zobrazit konkrétní sadu pravidel
- Seznam všech verzí rulesetu
- Zobrazení konkrétní verze rulesetu
- Seznam pravidel spravovaného rulesetu s určitým tagem
Seznam existujících sad pravidel
Vrátí seznam existujících sad pravidel na úrovni účtu nebo na úrovni zóny.
Použijte jeden z následujících endpointů API:
- Seznam sad pravidel na úrovni účtu
GET /accounts/{account_id}/rulesets - Seznam sad pravidel zóny
GET /zones/{zone_id}/rulesets
Výsledek obsahuje sady pravidel ve všech fázích na dané úrovni (účet nebo zóna). phase pole v každém prvku výsledku udává fáze kde je daná sada pravidel definována.
Seznam sad pravidel na úrovni zóny navíc obsahuje i sady pravidel na úrovni účtu, které můžete chtít nasadit do dané zóny.
Výsledek neobsahuje seznam pravidel v sadě pravidel. Další informace najdete v Zobrazení konkrétní verze rulesetu a zjistěte, jak získat seznam pravidel.
Příklad
Požadovaná oprávnění API tokenu
Alespoň jeden z následujících oprávnění tokenu je povinné:Response Compression WriteResponse Compression ReadConfig Settings WriteConfig Settings ReadDynamic URL Redirects WriteDynamic URL Redirects ReadCache Settings WriteCache Settings ReadCustom Errors WriteCustom Errors ReadOrigin WriteOrigin ReadManaged headers WriteManaged headers ReadZone Transform Rules WriteZone Transform Rules ReadMass URL Redirects WriteMass URL Redirects ReadMagic Firewall WriteMagic Firewall ReadL4 DDoS Managed Ruleset WriteL4 DDoS Managed Ruleset ReadHTTP DDoS Managed Ruleset WriteHTTP DDoS Managed Ruleset ReadSanitize WriteSanitize ReadTransform Rules WriteTransform Rules ReadSelect Configuration WriteSelect Configuration ReadBot Management WriteBot Management ReadZone WAF WriteZone WAF ReadAccount WAF WriteAccount WAF ReadAccount Rulesets ReadAccount Rulesets WriteLogs WriteLogs ReadLogs WriteLogs Read
curl "https://api.cloudflare.com/client/v4/zones/$ZONE_ID/rulesets" \
--request GET \
--header "Authorization: Bearer $CLOUDFLARE_API_TOKEN"{
"result": [
{
"id": "<PHASE_RULESET_ID>",
"name": "Zone-level phase entry point",
"description": "",
"kind": "zone",
"version": "5",
"last_updated": "2025-03-18T18:30:08.122758Z",
"phase": "http_request_firewall_managed"
}
],
"success": true,
"errors": [],
"messages": []
}Zobrazit konkrétní sadu pravidel
Vrátí vlastnosti nejnovější verze sady pravidel se zadaným ID sady pravidel.
Použijte jeden z následujících endpointů API:
- Získání sady pravidel účtu
GET /accounts/{account_id}/rulesets/{ruleset_id} - Získání vstupní sady pravidel účtu
GET /accounts/{account_id}/rulesets/phases/{phase_name}/entrypoint - Získání sady pravidel zóny
GET /zones/{zone_id}/rulesets/{ruleset_id} - Získání vstupní sady pravidel zóny
GET /zones/{zone_id}/rulesets/phases/{phase_name}/entrypoint
Rozhraní API vrátí 404 Not Found stavový kód HTTP za těchto podmínek:
- Pokud ruleset nelze najít.
- Pokud zadaný ruleset není spravovaným rulesetem, který má volající účet oprávnění spustit.
Příklad
Požadovaná oprávnění API tokenu
Alespoň jeden z následujících oprávnění tokenu je povinné:Response Compression WriteResponse Compression ReadConfig Settings WriteConfig Settings ReadDynamic URL Redirects WriteDynamic URL Redirects ReadCache Settings WriteCache Settings ReadCustom Errors WriteCustom Errors ReadOrigin WriteOrigin ReadManaged headers WriteManaged headers ReadZone Transform Rules WriteZone Transform Rules ReadMass URL Redirects WriteMass URL Redirects ReadMagic Firewall WriteMagic Firewall ReadL4 DDoS Managed Ruleset WriteL4 DDoS Managed Ruleset ReadHTTP DDoS Managed Ruleset WriteHTTP DDoS Managed Ruleset ReadSanitize WriteSanitize ReadTransform Rules WriteTransform Rules ReadSelect Configuration WriteSelect Configuration ReadBot Management WriteBot Management ReadZone WAF WriteZone WAF ReadAccount WAF WriteAccount WAF ReadAccount Rulesets ReadAccount Rulesets WriteLogs WriteLogs ReadLogs WriteLogs Read
curl "https://api.cloudflare.com/client/v4/zones/$ZONE_ID/rulesets/$RULESET_ID" \
--request GET \
--header "Authorization: Bearer $CLOUDFLARE_API_TOKEN"{
"result": {
"id": "<RULESET_ID>",
"name": "Zone-level phase entry point",
"description": "Executes a managed ruleset.",
"kind": "zone",
"version": "3",
"rules": [
{
"id": "<RULE_ID>",
"version": "1",
"action": "execute",
"expression": "true",
"action_parameters": {
"id": "<MANAGED_RULESET_ID>"
},
"last_updated": "2025-03-17T15:42:37.917815Z"
}
],
"last_updated": "2025-03-17T15:42:37.917815Z",
"phase": "http_request_firewall_managed"
},
"success": true,
"errors": [],
"messages": []
}Seznam všech verzí rulesetu
Vrátí seznam všech verzí sady pravidel.
Použijte jeden z následujících endpointů API:
- Seznam verzí rulesetu účtu
GET /accounts/{account_id}/rulesets/{ruleset_id}/versions - Seznam verzí entry point rulesetu účtu
GET /accounts/{account_id}/rulesets/phases/{phase_name}/entrypoint/versions - Seznam verzí rulesetu zóny
GET /zones/{zone_id}/rulesets/{ruleset_id}/versions - Seznam verzí entry point rulesetu zóny
GET /zones/{zone_id}/rulesets/phases/{phase_name}/entrypoint/versions
Výsledek obsahuje vlastnosti sady pravidel pro každou verzi, ale neobsahuje seznam pravidel. Další informace najdete v Zobrazení konkrétní verze rulesetu s pokyny, jak tyto informace získat.
Pokud zadaný ruleset vstupního bodu fáze neexistuje, tato metoda API vrátí prázdné pole v result .
Příklad
Požadovaná oprávnění API tokenu
Alespoň jeden z následujících oprávnění tokenu je povinné:Response Compression WriteResponse Compression ReadConfig Settings WriteConfig Settings ReadDynamic URL Redirects WriteDynamic URL Redirects ReadCache Settings WriteCache Settings ReadCustom Errors WriteCustom Errors ReadOrigin WriteOrigin ReadManaged headers WriteManaged headers ReadZone Transform Rules WriteZone Transform Rules ReadMass URL Redirects WriteMass URL Redirects ReadMagic Firewall WriteMagic Firewall ReadL4 DDoS Managed Ruleset WriteL4 DDoS Managed Ruleset ReadHTTP DDoS Managed Ruleset WriteHTTP DDoS Managed Ruleset ReadSanitize WriteSanitize ReadTransform Rules WriteTransform Rules ReadSelect Configuration WriteSelect Configuration ReadBot Management WriteBot Management ReadZone WAF WriteZone WAF ReadAccount WAF WriteAccount WAF ReadAccount Rulesets ReadAccount Rulesets WriteLogs WriteLogs ReadLogs WriteLogs Read
curl "https://api.cloudflare.com/client/v4/zones/$ZONE_ID/rulesets/$RULESET_ID/versions" \
--request GET \
--header "Authorization: Bearer $CLOUDFLARE_API_TOKEN"{
"result": [
{
"id": "<RULESET_ID>",
"name": "Zone Ruleset 1",
"description": "",
"kind": "zone",
"version": "1",
"last_updated": "2023-02-17T11:15:13.128705Z",
"phase": "http_request_firewall_managed"
},
{
"id": "<RULESET_ID>",
"name": "Zone Ruleset 1",
"description": "",
"kind": "zone",
"version": "2",
"last_updated": "2023-02-17T11:24:06.869326Z",
"phase": "http_request_firewall_managed"
}
],
"success": true,
"errors": [],
"messages": []
}Zobrazení konkrétní verze rulesetu
Vrátí konfiguraci konkrétní verze sady pravidel, včetně jejích pravidel.
Použijte jeden z následujících endpointů API:
- Získání verze sady pravidel účtu
GET /account/{account_id}/rulesets/{ruleset_id}/versions/{version_number} - Získání verze vstupní sady pravidel účtu
GET /accounts/{account_id}/rulesets/phases/{phase_name}/entrypoint/versions/{version_number} - Získání verze sady pravidel zóny
GET /zones/{zone_id}/rulesets/{ruleset_id}/versions/{version_number} - Získání verze vstupní sady pravidel zóny
GET /zones/{zone_id}/rulesets/phases/{phase_name}/entrypoint/versions/{version_number}
Pokud zadaný ruleset vstupního bodu fáze neexistuje, tato metoda API vrátí 404 Not Found stavový kód HTTP.
Příklad
Požadovaná oprávnění API tokenu
Alespoň jeden z následujících oprávnění tokenu je povinné:Response Compression WriteResponse Compression ReadConfig Settings WriteConfig Settings ReadDynamic URL Redirects WriteDynamic URL Redirects ReadCache Settings WriteCache Settings ReadCustom Errors WriteCustom Errors ReadOrigin WriteOrigin ReadManaged headers WriteManaged headers ReadZone Transform Rules WriteZone Transform Rules ReadMass URL Redirects WriteMass URL Redirects ReadMagic Firewall WriteMagic Firewall ReadL4 DDoS Managed Ruleset WriteL4 DDoS Managed Ruleset ReadHTTP DDoS Managed Ruleset WriteHTTP DDoS Managed Ruleset ReadSanitize WriteSanitize ReadTransform Rules WriteTransform Rules ReadSelect Configuration WriteSelect Configuration ReadBot Management WriteBot Management ReadZone WAF WriteZone WAF ReadAccount WAF WriteAccount WAF ReadAccount Rulesets ReadAccount Rulesets WriteLogs WriteLogs ReadLogs WriteLogs Read
curl "https://api.cloudflare.com/client/v4/zones/$ZONE_ID/rulesets/$RULESET_ID/versions/$RULESET_VERSION" \
--request GET \
--header "Authorization: Bearer $CLOUDFLARE_API_TOKEN"{
"result": {
"id": "<RULESET_ID>",
"name": "Zone-level phase entry point",
"description": "Executes a managed ruleset.",
"kind": "zone",
"version": "<RULESET_VERSION>",
"rules": [
{
"id": "<RULE_ID>",
"version": "1",
"action": "execute",
"expression": "true",
"action_parameters": {
"id": "<MANAGED_RULESET_ID>"
},
"last_updated": "2025-03-17T15:42:37.917815Z"
}
],
"last_updated": "2025-03-17T15:42:37.917815Z",
"phase": "http_request_firewall_managed"
},
"success": true,
"errors": [],
"messages": []
}Seznam pravidel spravovaného rulesetu s určitým tagem
Vrátí seznam všech pravidel ve spravované sadě pravidel s konkrétním štítkem.
- Seznam pravidel verze rulesetu účtu podle tagu
GET /accounts/{account_id}/rulesets/{ruleset_id}/versions/{version_number}/by_tag/{tag_name}
Příklad
Požadovaná oprávnění API tokenu
Alespoň jeden z následujících oprávnění tokenu je povinné:Mass URL Redirects WriteMass URL Redirects ReadMagic Firewall WriteMagic Firewall ReadL4 DDoS Managed Ruleset WriteL4 DDoS Managed Ruleset ReadTransform Rules WriteTransform Rules ReadSelect Configuration WriteSelect Configuration ReadAccount WAF WriteAccount WAF ReadAccount Rulesets ReadAccount Rulesets WriteLogs WriteLogs Read
curl "https://api.cloudflare.com/client/v4/accounts/$ACCOUNT_ID/rulesets/$RULESET_ID/versions/2/by_tag/wordpress" \
--request GET \
--header "Authorization: Bearer $CLOUDFLARE_API_TOKEN"{
"result": {
"id": "<MANAGED_RULESET_ID>",
"name": "Cloudflare Managed Ruleset",
"description": "Managed ruleset created by Cloudflare",
"kind": "managed",
"version": "2",
"rules": [
{
"id": "<RULE_ID_1>",
"version": "2",
"action": "log",
"categories": [
"cve-2014-5265",
"cve-2014-5266",
"cve-2014-5267",
"dos",
"drupal",
"wordpress"
],
"description": "Drupal, WordPress - DoS - XMLRPC - CVE:CVE-2014-5265, CVE:CVE-2014-5266, CVE:CVE-2014-5267",
"last_updated": "2025-03-19T16:54:32.942986Z",
"ref": "<RULE_REF_1>",
"enabled": true
},
{
"id": "<RULE_ID_2>",
"version": "2",
"action": "block",
"categories": ["broken-access-control", "cve-2018-12895", "wordpress"],
"description": "WordPress - Broken Access Control - CVE:CVE-2018-12895",
"last_updated": "2025-03-19T16:54:32.942986Z",
"ref": "<RULE_REF_2>",
"enabled": true
}
// (...)
],
"last_updated": "2025-03-19T16:54:32.942986Z",
"phase": "http_request_firewall_managed"
},
"success": true,
"errors": [],
"messages": []
}